aboutsummaryrefslogtreecommitdiff
path: root/commitquery/queries_new.go
diff options
context:
space:
mode:
authorGravatar Runxi Yu2026-03-29 15:00:06 +0000
committerGravatar Runxi Yu2026-03-29 15:00:06 +0000
commitecdae2b758ef6849222525c941574bbac13ea85c (patch)
tree11cce1a18e8d1384aa2c425ad4fc204d0349ff9a /commitquery/queries_new.go
parentcommitquery: Reorganize (diff)
signatureNo signature
commitquery: Use fetcher
Diffstat (limited to 'commitquery/queries_new.go')
-rw-r--r--commitquery/queries_new.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/commitquery/queries_new.go b/commitquery/queries_new.go
index 3c563c12..5eae7990 100644
--- a/commitquery/queries_new.go
+++ b/commitquery/queries_new.go
@@ -4,18 +4,18 @@ import (
"runtime"
commitgraphread "codeberg.org/lindenii/furgit/format/commitgraph/read"
- objectstore "codeberg.org/lindenii/furgit/object/store"
+ objectfetch "codeberg.org/lindenii/furgit/object/fetch"
)
// New builds one concurrent-safe commit query service over one object store
// and optional commit-graph reader.
//
// Labels: Deps-Borrowed, Life-Parent.
-func New(store objectstore.ReadingStore, graph *commitgraphread.Reader) *Queries {
+func New(fetcher *objectfetch.Fetcher, graph *commitgraphread.Reader) *Queries {
maxIdle := max(runtime.GOMAXPROCS(0), 1)
return &Queries{
- store: store,
+ fetcher: fetcher,
graph: graph,
maxIdle: maxIdle,
}
@@ -4,18 +4,18 @@ import (
)
-// New builds one concurrent-safe commit query service over one object store
+// New builds one concurrent-safe commit query service over one object fetcher
// and optional commit-graph reader.
//